@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """
@@ -37,6 +37,7 @@ LOG = logging.getLogger(".gui.utils.db")
 from ..lib.nameorigintype import NameOriginType
 from ..lib.surname import Surname
 from ..display.name import displayer as name_displayer
+from ..display.place import displayer as place_displayer
 from ..const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
 from ..constfunc import cuni
@@ -260,8 +261,15 @@ def get_participant_from_event(db, event_handle, all_=False):
     """
     participant = ""
     ellipses = False
-    result_list = list(db.find_backlink_handles(event_handle, 
-                             include_classes=['Person', 'Family']))
+    try:
+        result_list = list(db.find_backlink_handles(event_handle,
+                                 include_classes=['Person', 'Family']))
+    except:
+        # during a magic batch transaction find_backlink_handles tries to
+        # access the reference_map_referenced_map which is closed
+        # under those circumstances.
+        return ''
+
     #obtain handles without duplicates
     people = set([x[1] for x in result_list if x[0] == 'Person'])
     families = set([x[1] for x in result_list if x[0] == 'Family'])
@@ -327,15 +335,7 @@ def navigation_label(db, nav_type, handle):
     elif nav_type == 'Event':
         obj = db.get_event_from_handle(handle)
         if obj:
-            try:
-                who = get_participant_from_event(db, handle)
-            except:
-                # get_participants_from_event fails when called during a magic
-                # batch transaction because find_backlink_handles tries to
-                # access the reference_map_referenced_map which doesn't exist
-                # under those circumstances. Since setting the navigation_label
-                # is inessential, just accept this and go on.
-                who = ''
+            who = get_participant_from_event(db, handle)
             desc = obj.get_description()
             label = obj.get_type()
             if desc:
@@ -345,7 +345,7 @@ def navigation_label(db, nav_type, handle):
     elif nav_type == 'Place':
         obj = db.get_place_from_handle(handle)
         if obj:
-            label = obj.get_title()
+            label = place_displayer.display(db, obj)
     elif nav_type == 'Source':
         obj = db.get_source_from_handle(handle)
         if obj:
