@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
@@ -16,31 +17,33 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-# $Id$
-
 #------------------------------------------------------------------------
 #
 # python modules
 #
 #------------------------------------------------------------------------
-from __future__ import print_function
+# If you enable unicode_literals, some stuff needs fixing for win+py2, see #7162
+#from __future__ import print_function, unicode_literals
 import gettext
 import sys
 import os
 import codecs
 import locale
+import collections
 import logging
+
 LOG = logging.getLogger("." + __name__)
-LOG.addHandler(logging.NullHandler())
+LOG.propagate = True
 HAVE_ICU = False
+_icu_err = None
 _hdlr = None
 # GrampsLocale initialization comes before command-line argument
 # passing, so one must set the log level directly. The default is
 # logging.WARN. Uncomment the following to change it to logging.DEBUG:
-#LOG.setLevel(logging.DEBUG)
+# LOG.setLevel(logging.DEBUG)
 try:
     from icu import Locale, Collator
     HAVE_ICU = True
@@ -49,8 +52,10 @@ except ImportError:
         from PyICU import Locale, Collator
         HAVE_ICU = True
     except ImportError as err:
-        LOG.warning("ICU not loaded because %s. Localization will be impaired. "
-                    "Use your package manager to install PyICU", str(err))
+        # No logger, save the warning message for later.
+        _icu_err = ("ICU not loaded because %s. Localization will be impaired. "
+                    "Use your package manager to install PyICU" % str(err))
+
 ICU_LOCALES = None
 if HAVE_ICU:
     ICU_LOCALES = Locale.getAvailableLocales()
@@ -80,6 +85,7 @@ _LOCALE_NAMES = {
     'he': ('Hebrew_Israel', '1255', _("Hebrew")),
     'hr': ('Croatian_Croatia', '1250', _("Croatian")),
     'hu': ('Hungarian_Hungary', '1250', _("Hungarian")),
+    'is': ('Icelandic', '1252', _("Icelandic")),
     'it': ('Italian_Italy', '1252', _("Italian")),
     'ja': ('Japanese_Japan', '932', _("Japanese")),
     'lt': ('Lithuanian_Lithuania', '1252', _("Lithuanian")),
@@ -95,7 +101,7 @@ _LOCALE_NAMES = {
     'sk': ('Slovak_Slovakia', '1250', _("Slovak"),),
     'sl': ('Slovenian_Slovenia', '1250', _("Slovenian")),
     'sq': ('Albanian_Albania', '1250', _("Albanian")),
-    'sr': ('Serbian(Cyrillic)_Serbia and Montenegro', '1251', None), #Gramps's Serbian translation is not yet ready
+    'sr': ('Serbian (Cyrillic)_Serbia', '1251', _("Serbian")),
     'sv': ('Swedish_Sweden', '1252', _("Swedish")),
     'tr': ('Turkish_Turkey', '1254', _("Turkish")),
     'uk': ('Ukrainian_Ukraine', '1251', _("Ukrainian")),
@@ -141,18 +147,20 @@ class GrampsLocale(object):
     new GrampsLocale instance with the specified parameters, but any
     parameters left out will be filled in from the first instance.
 
-    @localedir: The full path to the top level directory containing
-                the translation files. Defaults to sys.prefix/share/locale.
+    :param localedir: The full path to the top level directory containing the
+                      translation files. Defaults to sys.prefix/share/locale.
 
-    @lang:      A single locale value which is used for unset locale.LC_FOO
-                settings.
+    :param lang: A single locale value which is used for unset locale.LC_FOO
+                 settings.
 
-    @domain:    The name of the applicable translation file. The default is
-                "gramps", indicating files in LC_MESSAGES named gramps.mo.
+    :param domain: The name of the applicable translation file. The default is
+                   "gramps", indicating files in LC_MESSAGES named gramps.mo.
 
-    @languages: A list of two or five character codes corresponding to
-                subidrectries in the localedir, e.g. "fr" or "zh_CN".
+    :param languages: String with a ':'-separated list of two or five character
+                      codes corresponding to subidrectries in the localedir,
+                      e.g.: "fr" or "zh_CN".
     """
+
     DEFAULT_TRANSLATION_STR = "default"
     __first_instance = None
     encoding = None
@@ -169,7 +177,7 @@ class GrampsLocale(object):
             and (localedir is None or localedir == cls.__first_instance.localedir)
             and (domain is None or domain == cls.__first_instance.localedomain)
             and (languages is None or len(languages) == 0 or
-                 languages == cls.__first_instance.languages)):
+                 languages == cls.__first_instance.language)):
             return cls.__first_instance
 
         return super(GrampsLocale, cls).__new__(cls)
@@ -200,7 +208,7 @@ class GrampsLocale(object):
                 self.lang = loc[0]
                 self.encoding = loc[1]
             else:
-                (lang, loc) = _check_mswin_locale(lang)
+                (lang, loc) = _check_mswin_locale(locale.getdefaultlocale()[0])
                 if lang:
                     self.lang = lang
                     self.encoding = loc[1]
@@ -228,10 +236,10 @@ class GrampsLocale(object):
         if not self.language:
             self.language = [self.lang[:5]]
 
-        if 'LC_COLLATE' in os.environ:
-            coll = os.environ['LC_COLLATE']
+        if 'COLLATION' in os.environ:
+            coll = os.environ['COLLATION']
             if HAVE_ICU:
-                if coll[:5] in ICU_LOCALES:
+                if coll[:2] in ICU_LOCALES:
                     self.collation = coll
                 else:
                     self.collation = self.lang
@@ -338,6 +346,9 @@ class GrampsLocale(object):
         else:
             self.collation = self.lang
 
+        if HAVE_ICU and 'COLLATION' in os.environ:
+            self.collation = os.environ['COLLATION']
+
         loc = locale.getlocale(locale.LC_NUMERIC)
         if loc and loc[0]:
             self.numeric = '.'.join(loc)
@@ -358,8 +369,7 @@ class GrampsLocale(object):
         from ctypes import cdll
         try:
             libintl = cdll.LoadLibrary('libintl-8')
-            libintl.bindtextdomain(localedomain,
-                                   localedir.encode(sys.getfilesystemencoding()))
+            libintl.bindtextdomain(localedomain, localedir)
             libintl.textdomain(localedomain)
             libintl.bind_textdomain_codeset(localedomain, "UTF-8")
 
@@ -377,6 +387,10 @@ class GrampsLocale(object):
         _hdlr.setFormatter(logging.Formatter(fmt="%(name)s.%(levelname)s: %(message)s"))
         LOG.addHandler(_hdlr)
 
+        #Now that we have a logger set up we can issue the icu error if needed.
+        if not HAVE_ICU:
+            LOG.warning(_icu_err)
+
         # Even the first instance can be overridden by passing lang
         # and languages to the constructor. If it isn't (which is the
         # expected behavior), do platform-specific setup:
@@ -410,7 +424,10 @@ class GrampsLocale(object):
 #Ensure that output is encoded correctly to stdout and stderr. This is
 #much less cumbersome and error-prone than encoding individual outputs
 #and better handles the differences between Python 2 and Python 3:
-        _encoding = sys.stdout.encoding or sys.getdefaultencoding()
+        try:
+            _encoding = sys.stdout.encoding or sys.getdefaultencoding()
+        except:
+            _encoding = "UTF-8"
         if sys.version_info[0] < 3:
             sys.stdout = codecs.getwriter(_encoding)(sys.stdout,
                                                      'backslashreplace')
@@ -429,6 +446,18 @@ class GrampsLocale(object):
         # 'UTF-8' suffix, because that's all that GtkBuilder can
         # digest.
 
+        # Gtk+ has an 'en' po, but we don't. This is worked-around for
+        # our GrampsTranslation class but that isn't used to retrieve
+        # translations in GtkBuilder (glade), a direct call to libintl
+        # (gettext) is. If 'en' is in the translation list it gets
+        # skipped in favor of the next language, which can cause
+        # inappropriate translations of strings in glade/ui files. To
+        # prevent this, if 'en' is in self.language it's the last
+        # entry:
+
+        if 'en' in self.language:
+            self.language = self.language[:self.language.index('en') + 1]
+
         # Linux note: You'll get unsupported locale errors from Gtk
         # and untranslated strings if the requisite UTF-8 locale isn't
         # installed. This is particularly a problem on Debian and
@@ -441,18 +470,20 @@ class GrampsLocale(object):
                 lang = '.'.join((check_lang[0], 'UTF-8'))
 
         os.environ["LANG"] = lang
-        os.environ["LANGUAGE"] = ':'.join([l for l in self.language])
+        #We need to convert 'en' and 'en_US' to 'C' to avoid confusing
+        #GtkBuilder when it's retrieving strings from our Glade files
+        #since we have neither an en.po nor an en_US.po.
+
+        os.environ["LANGUAGE"] = ':'.join(self.language)
 
         # GtkBuilder uses GLib's g_dgettext wrapper, which oddly is bound
         # with locale instead of gettext. Win32 doesn't support bindtextdomain.
         if self.localedir:
             if not sys.platform == 'win32':
-                try:
-                    locale.bindtextdomain(self.localedomain, self.localedir)
-                except AttributeError:
-                    pass
+                locale.bindtextdomain(self.localedomain, self.localedir)
             else:
-                self._win_bindtextdomain(self.localedomain, self.localedir)
+                self._win_bindtextdomain(self.localedomain.encode('utf-8'),
+                                         self.localedir.encode('utf-8'))
 
     def _init_secondary_locale(self):
         """
@@ -498,16 +529,17 @@ class GrampsLocale(object):
         if hasattr(self, 'initialized') and self.initialized:
             return
         _first = self._GrampsLocale__first_instance
-
+        self.localedir = None
         # Everything breaks without localedir, so get that set up
         # first.  Warnings are logged in _init_first_instance or
         # _init_secondary_locale if this comes up empty.
         if localedir and os.path.exists(os.path.abspath(localedir)):
             self.localedir = localedir
-        elif _first and _first.localedir:
+        elif (_first and hasattr(_first, 'localedir') and _first.localedir and
+              os.path.exists(os.path.abspath(_first.localedir))):
             self.localedir = _first.localedir
         else:
-            self.localedir = None
+            LOG.warn('Missing or invalid localedir %s; no translations will be available.', repr(localedir))
 
         self.lang = lang
         self.localedomain = domain or 'gramps'
@@ -518,10 +550,6 @@ class GrampsLocale(object):
         else:
             self.language = None
 
-         #For alternate collation sequences. Works only with ICU, and
-         #set only on Macs.
-        self.coll_qualifier = None
-        _first = self._GrampsLocale__first_instance
         if self == _first:
             self._GrampsLocale__init_first_instance()
         else:
@@ -552,7 +580,7 @@ class GrampsLocale(object):
 
         if _hdlr:
             LOG.removeHandler(_hdlr)
-
+            _hdlr = None
         self._dd = self._dp = None
         #Guards against running twice on the first instance.
         self.initialized = True
@@ -587,7 +615,7 @@ class GrampsLocale(object):
         if not languages or len(languages) == 0:
             LOG.warning("No language provided, using US English")
         else:
-            raise ValueError("No usable translations in %s" %
+            raise ValueError("No usable translations in %s for " %
                              ':'.join(languages))
         translator = GrampsNullTranslations()
         translator._language = "en"
@@ -626,7 +654,8 @@ class GrampsLocale(object):
         cached, set it from datehandler.LANG_TO_DISPLAY. If one isn't
         available for the selected locale, attempt to fall back on the
         first_instance's locale before settling on the 'C' displayer.
-        NB: This is the getter for the date_displayer property
+
+        .. note:: This is the getter for the date_displayer property
         """
         if self._dd:
             return self._dd
@@ -659,7 +688,8 @@ class GrampsLocale(object):
         cached, set it from datehandler.LANG_TO_PARSER. If one isn't
         available for the selected locale, attempt to fall back on the
         first_instance's locale before settling on the 'C' parser.
-        NB: This is the getter for the date_parser property
+
+        .. note:: This is the getter for the date_parser property
         """
         if self._dp:
             return self._dp
@@ -706,18 +736,19 @@ class GrampsLocale(object):
         """
         Get a translator for an addon.
 
-        filename - filename of a file in directory with full path, or
-                   None to get from self.
-        domain   - the name of the .mo file under the LANG/LC_MESSAGES dir
-        languages - a list of languages to force
-        returns  - a gettext.translation object
+        :param filename: filename of a file in directory with full path, or
+                         None to get from self.
+        :param domain: the name of the .mo file under the LANG/LC_MESSAGES dir
+        :param languages: a list of languages to force
+        :returns: a gettext.translation object
+
+        Example::
 
-        Example:
         _ = glocale.get_addon_translator(languages=["fr_BE.utf8"]).gettext
 
-        See the python gettext documentation.
-        Assumes path/filename
-            path/locale/LANG/LC_MESSAGES/addon.mo.
+        .. seealso:: the python gettext documentation.
+
+        Assumes path/filename = path/locale/LANG/LC_MESSAGES/addon.mo.
         """
         gramps_translator = self._get_translation()
 
@@ -824,21 +855,6 @@ class GrampsLocale(object):
         else:
             return _("See details")
 
-    def getfilesystemencoding(self):
-        """
-        If the locale isn't configured correctly, this will return
-        'ascii' or 'ANSI_X3.4-1968' or some other unfortunate
-        result. Current unix systems all encode filenames in utf-8,
-        and Microsoft Windows uses utf-16 (which they call mbcs). Make
-        sure we return the right value.
-        """
-        encoding = sys.getfilesystemencoding()
-
-        if encoding in ("utf-8", "UTF-8", "utf8", "UTF8", "mbcs", "MBCS"):
-            return encoding
-
-        return "utf-8"
-
     def sort_key(self, string):
         """
         Return a value suitable to pass to the "key" parameter of sorted()
@@ -848,12 +864,12 @@ class GrampsLocale(object):
             #ICU can digest strings and unicode
             return self.collator.getCollationKey(string).getByteArray()
         else:
+            if sys.version_info[0] < 3 and isinstance(string, unicode):
+                string = string.encode("utf-8", "replace")
+            if sys.version_info[0] >= 3 and isinstance(string, bytes):
+                string = string.decode("utf-8", "replace")
             try:
-                if sys.version_info[0] < 3 and isinstance(string, unicode):
-                    key = locale.strxfrm(string.encode("utf-8", "replace"))
-                else:
-                    key = locale.strxfrm(string)
-
+                key = locale.strxfrm(string)
             except Exception as err:
                 LOG.warn("Failed to obtain key for %s because %s",
                          self.collation, str(err))
@@ -937,6 +953,131 @@ class GrampsLocale(object):
 # Translations Classes
 #
 #-------------------------------------------------------------------------
+if sys.version_info < (3,0):
+    _LexemeBaseStr = unicode 
+    _isstring = lambda s: isinstance(s, basestring)
+else:
+    _LexemeBaseStr = str
+    _isstring = lambda s: isinstance(s, str)
+class Lexeme(_LexemeBaseStr):
+    r"""
+    Created with :meth:`~GrampsTranslations.lexgettext`
+
+    .. rubric:: Example
+
+    Python code::
+
+        _ = lexgettext
+        dec = _("localized lexeme inflections||December")
+        xmas = _("lexeme||Christmas")
+        text = _("{holiday} is celebrated in {month}".format(
+                    holiday=xmas, month=dec))
+        greeting = _("Merry {holiday}!").format(holiday=xmas)
+        XMAS = xmas.upper()
+        print ("\n".join([XMAS, text, greeting]))
+
+    Translation database (Russian example)::
+
+        msgid "lexeme||December"
+        msgstr "NOMINATIVE=декабрь|GENITIVE=декабря|ABLATIVE=декабрём|LOCATIVE=декабре"
+
+        msgid "lexeme||Christmas"
+        msgstr "NOMINATIVE=рождество|GENITIVE=рождества|ABLATIVE=рождеством"
+
+        msgid "{holiday} is celebrated in {month}"
+        msgstr "{holiday} празднуют в {month.f[LOCATIVE]}"
+
+        msgid "Merry {holiday}!"
+        msgstr "Счастливого {holiday.f[GENITIVE]}!"
+
+    Prints out::
+
+        In English locale:
+            CHRISTMAS 
+            Christmas is celebrated in December 
+            Merry Christmas!
+
+        In Russian locale:
+            РОЖДЕСТВО
+            рождество празднуют в декабре
+            Счастливого рождества!
+
+    .. rubric:: Description
+
+    Stores an arbitrary number of forms, e.g., inflections.
+    These forms are accessible under dictionary keys for each form.
+    The names of the forms are language-specific. They are assigned
+    by the human translator of the corresponding language (in XX.po)
+    as in the example above, 
+    see :meth:`~GrampsTranslations.lexgettext` docs 
+    for more info.
+
+    The translated format string can then refer to a specific form
+    of the lexeme using ``.``:attr:`~Lexeme.f` and square brackets: 
+    ``{holiday.f[GENITIVE]}``
+    expects holiday to be a Lexeme which has a form ``'GENITIVE'`` in it.
+
+    An instance of Lexeme can also be used as a regular unicode string.
+    In this case, the work will be delegated to the string for the very 
+    first form provided in the translated string. In the example above,
+    ``{holiday}`` in the translated string will expand to the Russian
+    nominative form for Christmas, and ``xmas.upper()`` will produce
+    the same nominative form in capital letters.
+
+    .. rubric:: Motivation
+
+    Lexeme is the term used in linguistics for the set of forms taken 
+    by a particular word, e.g. cases for a noun or tenses for a verb.
+    
+    Gramps often needs to compose sentences from several blocks of
+    text and single words, often by using python string formatting.
+
+    For instance, formatting a date range is done similarly to this::
+
+        _("Between {startdate_month} {startdate_year}"
+              "and {enddate_month} {enddate_year}").format(
+                 startdate_month = m1,
+                 startdate_year = y1,
+                 enddate_month = m2,
+                 enddate_year = y2)
+
+    To make such text translatable, the arguments injected into 
+    format string need to bear all the linguistical information
+    on how to plug them into a sentence, i.e., the forms, depending
+    on the linguistic context of where the argument appears.
+    The format string needs to select the relevant linguistic form.
+    This is why ``m1`` and ``m2`` are instances of :class:`~Lexeme`.
+
+    On the other hand, for languages where there is no linguistic
+    variation in such sentences, the code needs not to be aware of
+    the underlying :class:`~Lexeme` complexity; 
+    and so they can be processed just like simple strings 
+    both when passed around in the code and when formatted.
+    """
+
+    def __new__(cls, iterable, *args, **kwargs):
+        if _isstring(iterable):
+            newobj = _LexemeBaseStr.__new__(cls, iterable, *args, **kwargs)
+        else:
+            od = collections.OrderedDict(iterable)
+            l = list(od.values()) or [""]
+            newobj = _LexemeBaseStr.__new__(cls, l[0], *args, **kwargs) 
+            newobj._forms = od
+        return newobj
+
+    def variants(self):
+        """All lexeme forms, in the same order as given upon construction.
+        The first one returned is the default form, which is used when the
+        Lexeme instance is used in lieu of a string object.
+        
+        Same as ``f.values()``"""
+        return self._forms.values()
+
+    @property
+    def f(self):
+        """Dictionary of the lexeme forms"""
+        return self._forms
+
 class GrampsTranslations(gettext.GNUTranslations):
     """
     Overrides and extends gettext.GNUTranslations. See the Python gettext
@@ -951,6 +1092,7 @@ class GrampsTranslations(gettext.GNUTranslations):
     def gettext(self, msgid):
         """
         Obtain translation of gettext, return a unicode object
+
         :param msgid: The string to translated.
         :type msgid: unicode
         :returns: Translation or the original.
@@ -1010,6 +1152,32 @@ class GrampsTranslations(gettext.GNUTranslations):
             msgval = msgid[sep_idx+1:]
         return msgval
 
+    def lexgettext(self, msgid):
+        """
+        Extract all inflections of the same lexeme,
+        stripping the '|'-separated context using :meth:`~sgettext`
+
+        The *resulting* message provided by the translator
+        is supposed to be '|'-separated as well. 
+        The possible formats are either (1) a single string
+        for a language with no inflections, or (2) a list of
+        <inflection name>=<inflected form>, separated with '|'.
+        For example:
+
+           (1) "Uninflectable"
+           (2) "n=Inflected-nominative|g=Inflected-genitive|d=Inflected-dative"
+
+        See :class:`~Lexeme` documentation for detailed explanation and example.
+
+        :param msgid: The string to translated.
+        :type msgid: unicode
+        :returns: Translation or the original with context stripped.
+        :rtype: unicode (for option (1)) / Lexeme (option (2))
+        """
+        variants = self.sgettext(msgid).split('|')
+        return Lexeme([v.split('=') for v in variants]
+                ) if len(variants) > 1 else variants[0]
+
 class GrampsNullTranslations(gettext.NullTranslations):
     """
     Extends gettext.NullTranslations to provide the sgettext method.
@@ -1024,6 +1192,8 @@ class GrampsNullTranslations(gettext.NullTranslations):
             msgval = msgid[sep_idx+1:]
         return msgval
 
+    lexgettext = sgettext
+
     def language(self):
         """
         The null translation returns the raw msgids, which are in English
