@@ -19,7 +19,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 #-------------------------------------------------------------------------
@@ -97,7 +97,7 @@ class DisplayNameEditor(ManagedWindow):
     def __init__(self, uistate, dbstate, track, dialog):
         # Assumes that there are two methods: dialog.name_changed_check(), 
         # and dialog._build_custom_name_ui() 
-        ManagedWindow.__init__(self, uistate, [], DisplayNameEditor)
+        ManagedWindow.__init__(self, uistate, track, DisplayNameEditor)
         self.dialog = dialog
         self.dbstate = dbstate
         self.set_window(
@@ -136,7 +136,8 @@ UPPERCASE keyword forces uppercase. Extra parentheses, commas are removed. Other
         ManagedWindow.close(self, *obj)
         
     def build_menu_names(self, obj):
-        return (_(" Name Editor"), _("Preferences"))
+        # NameEditor is leaf of parent branch
+        return (_(" Name Editor"), None)
 
 
 #-------------------------------------------------------------------------
@@ -188,7 +189,6 @@ class ConfigureDialog(ManagedWindow):
         
         self.__setup_pages(configure_page_funcs)
         
-        self.window.show_all()
         self.show()
     
     def __setup_pages(self, configure_page_funcs):
@@ -231,12 +231,12 @@ class ConfigureDialog(ManagedWindow):
         except TypeError:
             print("WARNING: ignoring invalid value for '%s'" % constant)
             ErrorDialog(_("Invalid or incomplete format definition."), 
-            obj.get_text())
+                        obj.get_text(), parent=self.window)
             obj.set_text('<b>%s</b>')
         except ValueError:
             print("WARNING: ignoring invalid value for '%s'" % constant)
             ErrorDialog(_("Invalid or incomplete format definition."),
-            obj.get_text())
+                        obj.get_text(), parent=self.window)
             obj.set_text('<b>%s</b>')
         
         self.__config.set(constant, unicode(obj.get_text()))
@@ -770,7 +770,7 @@ class GrampsPreferences(ConfigureDialog):
             # check to see if this pattern already exists
             if self.__check_for_name(translation, node):
                 ErrorDialog(_("This format exists already."), 
-                                           translation)
+                                           translation, parent=self.window)
                 self.edit_button.emit('clicked')
                 return
             # else, change the name
@@ -998,6 +998,20 @@ class GrampsPreferences(ConfigureDialog):
         table.attach(obox, 1, 3, row, row+1, yoptions=0)
         row += 1
         
+        # Place format:
+        obox = Gtk.ComboBoxText()
+        formats = [_('Title'), _('Automatic')]
+        list(map(obox.append_text, formats))
+        active = config.get('preferences.place-format')
+        if active >= len(formats):
+            active = 0
+        obox.set_active(active)
+        obox.connect('changed', self.place_format_changed)
+        lwidget = BasicLabel("%s: " % _('Place format'))
+        table.attach(lwidget, 0, 1, row, row+1, yoptions=0)
+        table.attach(obox, 1, 3, row, row+1, yoptions=0)
+        row += 1
+        
         # Age precision:
         # precision=1 for "year", 2: "year, month" or 3: "year, month, days"
         obox = Gtk.ComboBoxText()
@@ -1155,8 +1169,16 @@ class GrampsPreferences(ConfigureDialog):
     def date_format_changed(self, obj):
         config.set('preferences.date-format', obj.get_active())
         OkDialog(_('Change is not immediate'), 
-                 _('Changing the data format will not take '
-                   'effect until the next time Gramps is started.'))
+                 _('Changing the date format will not take '
+                   'effect until the next time Gramps is started.'),
+                 parent=self.window)
+
+    def place_format_changed(self, obj):
+        config.set('preferences.place-format', obj.get_active())
+        OkDialog(_('Change is not immediate'), 
+                 _('Changing the place format will not take '
+                   'effect until the next time Gramps is started.'),
+                 parent=self.window)
 
     def date_calendar_changed(self, obj): 
         config.set('preferences.calendar-format-report', obj.get_active())
@@ -1324,10 +1346,7 @@ class GrampsPreferences(ConfigureDialog):
             return
 
         if len(addon_update_list) > 0:
-            try:
-                PluginWindows.UpdateAddons(self.uistate, [], addon_update_list)
-            except WindowActiveError:
-                pass
+            PluginWindows.UpdateAddons(addon_update_list, self.window)
         else:
             check_types = config.get('behavior.check-for-update-types')
             OkDialog(_("There are no available addons of this type"),
@@ -1371,12 +1390,13 @@ class GrampsPreferences(ConfigureDialog):
 
     def select_mediapath(self, *obj):
         f = Gtk.FileChooserDialog(
-            _("Select media directory"),
-            action=Gtk.FileChooserAction.SELECT_FOLDER,
-            buttons=(Gtk.STOCK_CANCEL,
-                     Gtk.ResponseType.CANCEL,
-                     Gtk.STOCK_APPLY,
-                     Gtk.ResponseType.OK))
+                title=_("Select media directory"),
+                parent=self.window,
+                action=Gtk.FileChooserAction.SELECT_FOLDER,
+                buttons=(Gtk.STOCK_CANCEL,
+                        Gtk.ResponseType.CANCEL,
+                        Gtk.STOCK_APPLY,
+                        Gtk.ResponseType.OK))
         mpath = self.dbstate.db.get_mediapath()
         if not mpath:
             mpath = HOME_DIR
@@ -1395,12 +1415,13 @@ class GrampsPreferences(ConfigureDialog):
 
     def select_dbpath(self, *obj):
         f = Gtk.FileChooserDialog(
-            _("Select database directory"),
-            action=Gtk.FileChooserAction.SELECT_FOLDER,
-            buttons=(Gtk.STOCK_CANCEL,
-                     Gtk.ResponseType.CANCEL,
-                     Gtk.STOCK_APPLY,
-                     Gtk.ResponseType.OK))
+                title=_("Select database directory"),
+                parent=self.window,
+                action=Gtk.FileChooserAction.SELECT_FOLDER,
+                buttons=(Gtk.STOCK_CANCEL,
+                        Gtk.ResponseType.CANCEL,
+                        Gtk.STOCK_APPLY,
+                        Gtk.ResponseType.OK))
         dbpath = config.get('behavior.database-path')
         if not dbpath:
             dbpath = os.path.join(HOME_DIR,'grampsdb')
@@ -1453,7 +1474,9 @@ class GrampsPreferences(ConfigureDialog):
             obj.set_text(str(intval))
 
     def build_menu_names(self, obj):
-        return (_('Preferences'), None)
+        # Preferences editor my open other dialog so let main dialog
+        # be leaf in branch
+        return (_('Preferences'), _('Preferences'))
 
     # FIXME: is this needed?
     def _set_button(self, stock):
