@@ -17,7 +17,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """
@@ -248,7 +248,7 @@ class DbManager(CLIDbManager):
 
         if store.get_value(node, STOCK_COL) == Gtk.STOCK_DIALOG_ERROR:
             path = conv_to_unicode(store.get_value(node, PATH_COL), 'utf8')
-            backup = os.path.join(path, u"person.gbkp")
+            backup = os.path.join(path, "person.gbkp")
             self.repair.set_sensitive(os.path.isfile(backup))
         else:
             self.repair.set_sensitive(False)
