@@ -18,7 +18,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 #-------------------------------------------------------------------------
 """
@@ -333,7 +333,7 @@ def get_child_unknown(level, inlaw=""):
     else:
         return "un descendant lointain%s" % inlaw
 
-def get_sibling_unknown(inlaw=""):
+def get_sibling_unknown(Ga, inlaw=""):
     """
     sibling of an ancestor, gender = unknown
     """
@@ -653,7 +653,7 @@ class RelationshipCalculator(gramps.gen.relationship.RelationshipCalculator):
                 elif gender_b == Person.FEMALE:
                     rel_str = "la tante lointaine" + bygen % (Ga + 1)
                 elif gender_b == Person.UNKNOWN:
-                    rel_str = get_sibling_unknown(inlaw)
+                    rel_str = get_sibling_unknown(Ga, inlaw)
                 else:
                     return rel_str
         elif Ga == 1:
@@ -672,7 +672,7 @@ class RelationshipCalculator(gramps.gen.relationship.RelationshipCalculator):
                     rel_str = "la nièce lointaine%s (%dème génération)" % \
                         (inlaw, Gb)
                 elif gender_b == Person.UNKNOWN:
-                    rel_str = get_sibling_unknown(inlaw)
+                    rel_str = get_sibling_unknown(Ga, inlaw)
                 else:
                     return rel_str
         elif Ga == Gb:
@@ -684,7 +684,7 @@ class RelationshipCalculator(gramps.gen.relationship.RelationshipCalculator):
             elif gender_b == Person.FEMALE:
                 rel_str = get_cousine(Ga - 1, 0, inlaw=inlaw)
             elif gender_b == Person.UNKNOWN:
-                rel_str = get_sibling_unknown(inlaw)
+                rel_str = get_sibling_unknown(Ga, inlaw)
             else:
                 return rel_str
         elif Ga > 1 and Ga > Gb:
