@@ -18,7 +18,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """Place Report"""
@@ -48,6 +48,7 @@ from gramps.gen.plug.docgen import (IndexMark, FontStyle, ParagraphStyle,
 from gramps.gen.proxy import PrivateProxyDb
 from gramps.gen.sort import Sort
 from gramps.gen.utils.location import get_main_location
+from gramps.gen.display.place import displayer as place_displayer
 from gramps.gen.lib import PlaceType
 
 class PlaceReport(Report):
@@ -163,9 +164,10 @@ class PlaceReport(Report):
             self._("State: %s") % location.get(PlaceType.STATE, ''),
             self._("Country: %s ") % location.get(PlaceType.COUNTRY, '')]
         self.doc.start_paragraph("PLC-PlaceTitle")
+        place_title = place_displayer.display(self.database, place)
         self.doc.write_text(("%(nbr)s. %(place)s") % 
                                 {'nbr' : place_nbr,
-                                 'place' : place.get_title()})
+                                 'place' : place_title})
         self.doc.end_paragraph()
 
         for item in place_details:
@@ -178,7 +180,7 @@ class PlaceReport(Report):
         This procedure writes out each of the events related to the place
         """
         event_handles = [event_handle for (object_type, event_handle) in
-                         self.database.find_backlink_handles(handle)]
+                         self.database.find_backlink_handles(handle, ['Event'])]
         event_handles.sort(key=self.sort.by_date_key)
 
         if event_handles:
@@ -254,7 +256,7 @@ class PlaceReport(Report):
         This procedure writes out each of the people related to the place
         """
         event_handles = [event_handle for (object_type, event_handle) in
-                         self.database.find_backlink_handles(handle)]
+                         self.database.find_backlink_handles(handle, ['Event'])]
 
         if event_handles:
             self.doc.start_paragraph("PLC-Section")
@@ -282,11 +284,6 @@ class PlaceReport(Report):
                     person = self.database.get_person_from_handle(ref_handle)
                     nameEntry = "%s (%s)" % (self._nd.display(person),
                                              person.get_gramps_id())
-                    if nameEntry in person_dict:
-                        person_dict[nameEntry].append(evt_handle)
-                    else:
-                        person_dict[nameEntry] = []
-                        person_dict[nameEntry].append(evt_handle)
                 else:
                     family = self.database.get_family_from_handle(ref_handle)
                     f_handle = family.get_father_handle()
@@ -300,7 +297,7 @@ class PlaceReport(Report):
                                           'father_id' : father.get_gramps_id(),
                                           'mother' : self._nd.display(mother),
                                           'mother_id' : mother.get_gramps_id()}
-                    else:
+                    elif f_handle or m_handle:
                         if f_handle:
                             p_handle = f_handle
                         else:
@@ -310,12 +307,15 @@ class PlaceReport(Report):
                         nameEntry = "%s (%s)" % \
                                      (self._nd.display(person),
                                       person.get_gramps_id())
-
-                    if nameEntry in person_dict:
-                        person_dict[nameEntry].append(evt_handle)
                     else:
-                        person_dict[nameEntry] = []
-                        person_dict[nameEntry].append(evt_handle)
+                        # No parents - bug #7299
+                        continue
+
+                if nameEntry in person_dict:
+                    person_dict[nameEntry].append(evt_handle)
+                else:
+                    person_dict[nameEntry] = []
+                    person_dict[nameEntry].append(evt_handle)
 
         keys = list(person_dict.keys())
         keys.sort()
@@ -329,6 +329,10 @@ class PlaceReport(Report):
                     date = self._get_date(event.get_date_object())
                     descr = event.get_description()
                     event_type = self._(self._get_type(event.get_type()))
+                else:
+                    date = ''
+                    descr = ''
+                    event_type = ''
                 event_details = [people, event_type, descr, date]
                 self.doc.start_row()
                 for detail in event_details:
