@@ -17,7 +17,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """
@@ -51,6 +51,7 @@ from gramps.gen.lib import EventRoleType, EventType
 from gramps.gen.config import config
 from gramps.gen.datehandler import displayer
 from gramps.gen.display.name import displayer as _nd
+from gramps.gen.display.place import displayer as _pd
 from gramps.gen.utils.place import conv_lat_lon
 from gramps.gui.views.navigationview import NavigationView
 from gramps.gui.views.bookmarks import FamilyBookmarks
@@ -120,6 +121,7 @@ class GeoFamClose(GeoGraphyView):
         ('geography.lock', False),
         ('geography.center-lat', 0.0),
         ('geography.center-lon', 0.0),
+        ('geography.use-keypad', True),
 
         ('geography.map_service', constants.OPENSTREETMAP),
         ('geography.max_places', 5000),
@@ -253,7 +255,7 @@ class GeoFamClose(GeoGraphyView):
                 self.message_layer.add_message(_("The other family : %s" % _("Unknown")))
             if self.reffamily_bookmark is None:
                 self.reffamily_bookmark = self.reffamily.get_handle()
-                self.add_bookmark(None, self.reffamily_bookmark)
+                self.add_bookmark_from_popup(None, self.reffamily_bookmark)
         else:
             self.message_layer.add_message(_("You must choose one reference family."))
             self.message_layer.add_message(_("Go to the family view and select "
@@ -450,7 +452,7 @@ class GeoFamClose(GeoGraphyView):
                         latitude = place.get_latitude()
                         latitude, longitude = conv_lat_lon(latitude,
                                                            longitude, "D.D8")
-                        descr = place.get_title()
+                        descr = _pd.display(dbstate.db, place)
                         evt = EventType(event.get_type())
                         descr1 = _("%(eventtype)s : %(name)s") % {
                                         'eventtype': evt,
@@ -502,7 +504,7 @@ class GeoFamClose(GeoGraphyView):
                                         latitude = place.get_latitude()
                                         latitude, longitude = conv_lat_lon(
                                                   latitude, longitude, "D.D8")
-                                        descr = place.get_title()
+                                        descr = _pd.display(dbstate.db, place)
                                         evt = EventType(
                                                   event.get_type())
                                         eyear = str("%04d" % event.get_date_object().to_calendar(self.cal).get_year()) + \
