@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """
@@ -63,6 +63,7 @@ from gramps.gui.views.navigationview import NavigationView
 from gramps.gui.editors import EditPerson, EditFamily
 from gramps.gui.editors import FilterEditor
 from gramps.gen.display.name import displayer as name_displayer
+from gramps.gen.display.place import displayer as place_displayer
 from gramps.gen.utils.file import media_path_full
 from gramps.gen.utils.alive import probably_alive
 from gramps.gui.utils import open_file_with_default_application
@@ -716,7 +717,7 @@ class RelationshipView(NavigationView):
             dobj = event.get_date_object()
             phandle = event.get_place_handle()
             if phandle:
-                pname = self.place_name(phandle)
+                pname = place_displayer.display_event(self.dbstate.db, event)
             else:
                 pname = None
 
@@ -744,7 +745,7 @@ class RelationshipView(NavigationView):
             dobj = event.get_date_object()
             phandle = event.get_place_handle()
             if phandle:
-                pname = self.place_name(phandle)
+                pname = place_displayer.display_event(self.dbstate.db, event)
             else:
                 pname = None
 
@@ -1272,10 +1273,6 @@ class RelationshipView(NavigationView):
         msg = _('Relationship type: %s') % cgi.escape(str(family.get_relationship()))
         box.add(widgets.MarkupLabel(msg))
 
-    def place_name(self, handle):
-        p = self.dbstate.db.get_place_from_handle(handle)
-        return p.get_title()
-
     def write_relationship_events(self, vbox, family):
         value = False
         for event_ref in family.get_event_ref_list():
@@ -1294,7 +1291,7 @@ class RelationshipView(NavigationView):
             dobj = event.get_date_object()
             phandle = event.get_place_handle()
             if phandle:
-                pname = self.place_name(phandle)
+                pname = place_displayer.display_event(self.dbstate.db, event)
             else:
                 pname = None
 
